@@ -5,11 +5,11 @@ from PySide.QtCore import *
 from PySide.QtGui import *
 
 # Some global variables
-Cps2GuiVersion = "0.0.1-4"
+Cps2GuiVersion = "0.0.1-5"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
-Cps2_KeyCfgFile = Home + '/.cps2emu/keyconfig.cfg'
+Cps2_KeyCfgFile = Home + '/.config/cps2emu/cps2emu.conf'
 Cps2Gui_CfgFile = Home + '/.cps2-gui/cps2-gui.cfg'
 Cps2_GameFile = '/opt/cps2-gui/zipname.cps2'
 P1buttons = ""
@@ -406,47 +406,14 @@ class keyWindow(QDialog):
         super(keyWindow, self).__init__(parent)
         self.setWindowTitle("Cps2-gui button config")
 	LineNbr=1
-        f = open(Cps2_KeyCfgFile)
-        for line in f:
-		if LineNbr == 1:
-			UP=line.strip()
-		if LineNbr == 2:
-			DOWN=line.strip()
-		if LineNbr == 3:
-			LEFT=line.strip()
-		if LineNbr == 4:
-			RIGHT=line.strip()
-		if LineNbr == 5:
-			START=line.strip()
-		if LineNbr == 6:
-			COIN=line.strip()
-		if LineNbr == 7:
-			BUTTON1=line.strip()
-		if LineNbr == 8:
-			BUTTON2=line.strip()
-		if LineNbr == 9:
-			BUTTON3=line.strip()
-		if LineNbr == 10:
-			BUTTON4=line.strip()
-		if LineNbr == 11:
-			BUTTON5=line.strip()
-		if LineNbr == 12:
-			BUTTON6=line.strip()
-		if LineNbr == 13:
-			AUTOFIRE1=line.strip()
-		if LineNbr == 14:
-			AUTOFIRE2=line.strip()
-		if LineNbr == 15:
-			AUTOFIRE3=line.strip()
-		LineNbr +=1
-        f.close()
+        self.options = parse_config(self,Cps2_KeyCfgFile)
 	# Layout
 	area = QScrollArea(self)
 	lay = QVBoxLayout(self)
 	lay.addWidget(area)
 	wg = QWidget()
 	area.setWidget(wg)
-	wg.resize(750,1030);
+	wg.resize(750,1350);
 	grid = QGridLayout(wg)
 	wg.show()
 	area.show()
@@ -454,128 +421,203 @@ class keyWindow(QDialog):
         font = QFont()
         font.setPointSize(24)
 	minKeyValue=1
-	maxKeyValue=307
+	maxKeyValue=313
         self.saveKeyButton = QPushButton("SAVE",self)
         self.saveKeyButton.setStyleSheet(
 	"QPushButton { color: red; font:bold; }"
       		) 
-	grid.addWidget(self.saveKeyButton, 1, 0)
+	grid.addWidget(QLabel("<font color=red>Save below!</font>"), 1, 0)
+        grid.addWidget(self.saveKeyButton,22,0,1,3)
 	grid.addWidget(QLabel("<center>PLAYER 1</center>"), 1, 1)
 	grid.addWidget(QLabel("<center>[pick]</center>"), 1, 2)
 	# Add button list
 	cntr=2
 	for pButton in ['UP','DOWN','LEFT','RIGHT','START','COIN','BUTTON1','BUTTON2','BUTTON3','BUTTON4'\
-                        ,'BUTTON5','BUTTON6','AUTOFIRE1','AUTOFIRE2','AUTOFIRE3']:
+                        ,'BUTTON5','BUTTON6','AUTOFIRE1','AUTOFIRE2','AUTOFIRE3','RESET','MENU','SERVICE'\
+			,'EXIT']:
 		grid.addWidget(QLabel(pButton), cntr, 0)
 		cntr=cntr+1
 	# UP
-	self.P1UpValue = QLineEdit(UP)
-	self.P1UpValue.setAlignment(Qt.AlignHCenter);
-	grid.addWidget(self.P1UpValue, 2, 1)
-	self.P1UpValue.setEnabled(False)
-	self.P1UpButton = MyKeyPressed("key",self)
-	grid.addWidget(self.P1UpButton, 2, 2)
+        self.P1UpkeySpinBox = QDoubleSpinBox()
+        self.P1UpkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1UpkeySpinBox.setValue(float(self.options["UP"]))
+        self.P1UpkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1UpkeySpinBox, 2, 1)
+        self.P1UpButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1UpButton, 2, 2)
 	# DOWN
-	self.P1DownValue = QLineEdit(DOWN)
-	self.P1DownValue.setAlignment(Qt.AlignHCenter);
-	self.P1DownValue.setEnabled(False)
-	grid.addWidget(self.P1DownValue, 3, 1)
-	self.P1DownButton = MyKeyPressed("key",self)
-	grid.addWidget(self.P1DownButton, 3, 2)
+        self.P1DownkeySpinBox = QDoubleSpinBox()
+        self.P1DownkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1DownkeySpinBox.setValue(float(self.options["DOWN"]))
+        self.P1DownkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1DownkeySpinBox, 3, 1)
+        self.P1DownButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1DownButton, 3, 2)
+
 	# LEFT
-	self.P1LeftValue = QLineEdit(LEFT)
-	self.P1LeftValue.setAlignment(Qt.AlignHCenter);
-	self.P1LeftValue.setEnabled(False)
-	grid.addWidget(self.P1LeftValue, 4, 1)
-	self.P1LeftButton = MyKeyPressed("key",self)
-	grid.addWidget(self.P1LeftButton, 4, 2)
+        self.P1LeftkeySpinBox = QDoubleSpinBox()
+        self.P1LeftkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1LeftkeySpinBox.setValue(float(self.options["LEFT"]))
+        self.P1LeftkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1LeftkeySpinBox, 4, 1)
+        self.P1LeftButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1LeftButton, 4, 2)
 	# RIGHT
-	self.P1RightValue = QLineEdit(RIGHT)
-	self.P1RightValue.setAlignment(Qt.AlignHCenter);
-	self.P1RightValue.setEnabled(False)
-	grid.addWidget(self.P1RightValue, 5, 1)
-	self.P1RightButton = MyKeyPressed("key",self)
-	grid.addWidget(self.P1RightButton, 5, 2)
+        self.P1RightkeySpinBox = QDoubleSpinBox()
+        self.P1RightkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1RightkeySpinBox.setValue(float(self.options["RIGHT"]))
+        self.P1RightkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1RightkeySpinBox, 5, 1)
+        self.P1RightButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1RightButton, 5, 2)
 	# START
-	self.P1StartValue = QLineEdit(START)
-	self.P1StartValue.setAlignment(Qt.AlignHCenter);
-	self.P1StartValue.setEnabled(False)
-	grid.addWidget(self.P1StartValue, 6, 1)
-	self.P1StartButton = MyKeyPressed("key",self)
-	grid.addWidget(self.P1StartButton, 6, 2)
+        self.P1StartkeySpinBox = QDoubleSpinBox()
+        self.P1StartkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1StartkeySpinBox.setValue(float(self.options["START"]))
+        self.P1StartkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1StartkeySpinBox, 6, 1)
+        self.P1StartButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1StartButton, 6, 2)
 	# COIN
-	self.P1CoinValue = QLineEdit(COIN)
-	self.P1CoinValue.setAlignment(Qt.AlignHCenter);
-	self.P1CoinValue.setEnabled(False)
-	grid.addWidget(self.P1CoinValue, 7, 1)
-	self.P1CoinButton = MyKeyPressed("key",self)
-	grid.addWidget(self.P1CoinButton, 7, 2)
+        self.P1CoinkeySpinBox = QDoubleSpinBox()
+        self.P1CoinkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1CoinkeySpinBox.setValue(float(self.options["COIN"]))
+        self.P1CoinkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1CoinkeySpinBox, 7, 1)
+        self.P1CoinButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1CoinButton, 7, 2)
 	# BUTTON1
-	self.P1Button1Value = QLineEdit(BUTTON1)
-	self.P1Button1Value.setAlignment(Qt.AlignHCenter);
-	self.P1Button1Value.setEnabled(False)
-	grid.addWidget(self.P1Button1Value, 8, 1)
-	self.P1Button1Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Button1Button, 8, 2)
+        self.P1Button1keySpinBox = QDoubleSpinBox()
+        self.P1Button1keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Button1keySpinBox.setValue(float(self.options["BUTTON1"]))
+        self.P1Button1keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Button1keySpinBox, 8, 1)
+        self.P1Button1Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Button1Button, 8, 2)
 	# BUTTON2
-	self.P1Button2Value = QLineEdit(BUTTON2)
-	self.P1Button2Value.setAlignment(Qt.AlignHCenter);
-	self.P1Button2Value.setEnabled(False)
-	grid.addWidget(self.P1Button2Value, 9, 1)
-	self.P1Button2Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Button2Button, 9, 2)
+        self.P1Button2keySpinBox = QDoubleSpinBox()
+        self.P1Button2keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Button2keySpinBox.setValue(float(self.options["BUTTON2"]))
+        self.P1Button2keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Button2keySpinBox, 9, 1)
+        self.P1Button2Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Button2Button, 9, 2)
 	# BUTTON3
-	self.P1Button3Value = QLineEdit(BUTTON3)
-	self.P1Button3Value.setAlignment(Qt.AlignHCenter);
-	self.P1Button3Value.setEnabled(False)
-	grid.addWidget(self.P1Button3Value, 10, 1)
-	self.P1Button3Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Button3Button, 10, 2)
+        self.P1Button3keySpinBox = QDoubleSpinBox()
+        self.P1Button3keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Button3keySpinBox.setValue(float(self.options["BUTTON3"]))
+        self.P1Button3keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Button3keySpinBox, 10, 1)
+        self.P1Button3Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Button3Button, 10, 2)
 	# BUTTON4
-	self.P1Button4Value = QLineEdit(BUTTON4)
-	self.P1Button4Value.setAlignment(Qt.AlignHCenter);
-	self.P1Button4Value.setEnabled(False)
-	grid.addWidget(self.P1Button4Value, 11, 1)
-	self.P1Button4Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Button4Button, 11, 2)
-	# BUTTON5
-	self.P1Button5Value = QLineEdit(BUTTON5)
-	self.P1Button5Value.setAlignment(Qt.AlignHCenter);
-	self.P1Button5Value.setEnabled(False)
-	grid.addWidget(self.P1Button5Value, 12, 1)
-	self.P1Button5Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Button5Button, 12, 2)
+        self.P1Button4keySpinBox = QDoubleSpinBox()
+        self.P1Button4keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Button4keySpinBox.setValue(float(self.options["BUTTON4"]))
+        self.P1Button4keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Button4keySpinBox, 11, 1)
+        self.P1Button4Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Button4Button, 11, 2)
+	# BUTTON
+        self.P1Button5keySpinBox = QDoubleSpinBox()
+        self.P1Button5keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Button5keySpinBox.setValue(float(self.options["BUTTON5"]))
+        self.P1Button5keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Button5keySpinBox, 12, 1)
+        self.P1Button5Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Button5Button, 12, 2)
 	# BUTTON6
-	self.P1Button6Value = QLineEdit(BUTTON6)
-	self.P1Button6Value.setAlignment(Qt.AlignHCenter);
-	self.P1Button6Value.setEnabled(False)
-	grid.addWidget(self.P1Button6Value, 13, 1)
-	self.P1Button6Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Button6Button, 13, 2)
+        self.P1Button6keySpinBox = QDoubleSpinBox()
+        self.P1Button6keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Button6keySpinBox.setValue(float(self.options["BUTTON6"]))
+        self.P1Button6keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Button6keySpinBox, 13, 1)
+        self.P1Button6Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Button6Button, 13, 2)
 	# AUTOFIRE1
-	self.P1Autofire1Value = QLineEdit(AUTOFIRE1)
-	self.P1Autofire1Value.setAlignment(Qt.AlignHCenter);
-	self.P1Autofire1Value.setEnabled(False)
-	grid.addWidget(self.P1Autofire1Value, 14, 1)
-	self.P1Autofire1Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Autofire1Button, 14, 2)
+        self.P1Autofire1keySpinBox = QDoubleSpinBox()
+        self.P1Autofire1keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Autofire1keySpinBox.setValue(float(self.options["AUTOFIRE1"]))
+        self.P1Autofire1keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Autofire1keySpinBox, 14, 1)
+        self.P1Autofire1Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Autofire1Button, 14, 2)
 	# AUTOFIRE2
-	self.P1Autofire2Value = QLineEdit(AUTOFIRE2)
-	self.P1Autofire2Value.setAlignment(Qt.AlignHCenter);
-	self.P1Autofire2Value.setEnabled(False)
-	grid.addWidget(self.P1Autofire2Value, 15, 1)
-	self.P1Autofire2Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Autofire2Button, 15, 2)
+        self.P1Autofire2keySpinBox = QDoubleSpinBox()
+        self.P1Autofire2keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Autofire2keySpinBox.setValue(float(self.options["AUTOFIRE2"]))
+        self.P1Autofire2keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Autofire2keySpinBox, 15, 1)
+        self.P1Autofire2Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Autofire2Button, 15, 2)
 	# AUTOFIRE3
-	self.P1Autofire3Value = QLineEdit(AUTOFIRE3)
-	self.P1Autofire3Value.setAlignment(Qt.AlignHCenter);
-	self.P1Autofire3Value.setEnabled(False)
-	grid.addWidget(self.P1Autofire3Value, 16, 1)
-	self.P1Autofire3Button = MyKeyPressed("key",self)
-	grid.addWidget(self.P1Autofire3Button, 16, 2)
+        self.P1Autofire3keySpinBox = QDoubleSpinBox()
+        self.P1Autofire3keySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1Autofire3keySpinBox.setValue(float(self.options["AUTOFIRE3"]))
+        self.P1Autofire3keySpinBox.setDecimals(0)
+        grid.addWidget(self.P1Autofire3keySpinBox, 16, 1)
+        self.P1Autofire3Button = MyKeyPressed("key",self)
+        grid.addWidget(self.P1Autofire3Button, 16, 2)
+	# RESET
+        self.P1ResetkeySpinBox = QDoubleSpinBox()
+        self.P1ResetkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1ResetkeySpinBox.setValue(float(self.options["RESET"]))
+        self.P1ResetkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1ResetkeySpinBox, 17, 1)
+        self.P1ResetButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1ResetButton, 17, 2)
+	# MENU
+        self.P1MenukeySpinBox = QDoubleSpinBox()
+        self.P1MenukeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1MenukeySpinBox.setValue(float(self.options["MENU"]))
+        self.P1MenukeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1MenukeySpinBox, 18, 1)
+        self.P1MenuButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1MenuButton, 18, 2)
+	# SERVICE
+        self.P1ServicekeySpinBox = QDoubleSpinBox()
+        self.P1ServicekeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1ServicekeySpinBox.setValue(float(self.options["SERVICE"]))
+        self.P1ServicekeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1ServicekeySpinBox, 19, 1)
+        self.P1ServiceButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1ServiceButton, 19, 2)
+	# EXIT
+        self.P1ExitkeySpinBox = QDoubleSpinBox()
+        self.P1ExitkeySpinBox.setRange(minKeyValue, maxKeyValue)
+        self.P1ExitkeySpinBox.setValue(float(self.options["EXIT"]))
+        self.P1ExitkeySpinBox.setDecimals(0)
+        grid.addWidget(self.P1ExitkeySpinBox, 20, 1)
+        self.P1ExitButton = MyKeyPressed("key",self)
+        grid.addWidget(self.P1ExitButton, 20, 2)
+	# SIXAXIS
+        self.P1SixaxisPushButton = QPushButton("Use Sixaxis default",self)
+	self.P1SixaxisPushButton.setCheckable(True)
+        grid.addWidget(self.P1SixaxisPushButton,21,0,1,3)
+	if self.options["SIXAXIS"] == "1":
+            self.P1SixaxisPushButton.setChecked(True)
 
 	self.setLayout(grid)
 
+        self.connect(self.P1UpkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1DownkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1RightkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1LeftkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1StartkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1CoinkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Button1keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Button2keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Button3keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Button4keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Button5keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Button6keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Autofire1keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Autofire2keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1Autofire3keySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1ResetkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1MenukeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1ServicekeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
+        self.connect(self.P1ExitkeySpinBox, SIGNAL('valueChanged(double)'), self.change_value)
 	self.connect(self.P1UpButton, SIGNAL("keyPressed"),self.P1updateUp)
 	self.connect(self.P1DownButton, SIGNAL("keyPressed"),self.P1updateDown)
 	self.connect(self.P1RightButton, SIGNAL("keyPressed"),self.P1updateRight)
@@ -591,78 +633,123 @@ class keyWindow(QDialog):
 	self.connect(self.P1Autofire1Button, SIGNAL("keyPressed"),self.P1updateAutofire1)
 	self.connect(self.P1Autofire2Button, SIGNAL("keyPressed"),self.P1updateAutofire2)
 	self.connect(self.P1Autofire3Button, SIGNAL("keyPressed"),self.P1updateAutofire3)
+	self.connect(self.P1ResetButton, SIGNAL("keyPressed"),self.P1updateReset)
+	self.connect(self.P1MenuButton, SIGNAL("keyPressed"),self.P1updateMenu)
+	self.connect(self.P1ServiceButton, SIGNAL("keyPressed"),self.P1updateService)
+	self.connect(self.P1ExitButton, SIGNAL("keyPressed"),self.P1updateExit)
+	self.connect(self.P1SixaxisPushButton, SIGNAL("clicked()"),self.P1updateSixaxis)
 	self.connect(self.saveKeyButton, SIGNAL("clicked()"),self.SaveKeys)
 
-    def P1updateUp(self):
-	self.P1UpValue.setText(AsciiVal)
-
-    def P1updateDown(self):
-	self.P1DownValue.setText(AsciiVal)
-
     def P1updateRight(self):
-	self.P1RightValue.setText(AsciiVal)
+        self.P1RightkeySpinBox.setValue(float(AsciiVal))
 
     def P1updateLeft(self):
-	self.P1LeftValue.setText(AsciiVal)
+        self.P1LeftkeySpinBox.setValue(float(AsciiVal))
+
+    def P1updateUp(self):
+        self.P1UpkeySpinBox.setValue(float(AsciiVal))
+
+    def P1updateDown(self):
+        self.P1DownkeySpinBox.setValue(float(AsciiVal))
 
     def P1updateStart(self):
-	self.P1StartValue.setText(AsciiVal)
+        self.P1StartkeySpinBox.setValue(float(AsciiVal))
 
     def P1updateCoin(self):
-	self.P1CoinValue.setText(AsciiVal)
+        self.P1CoinkeySpinBox.setValue(float(AsciiVal))
 
     def P1updateButton1(self):
-	self.P1Button1Value.setText(AsciiVal)
+        self.P1Button1keySpinBox.setValue(float(AsciiVal))
 
     def P1updateButton2(self):
-	self.P1Button2Value.setText(AsciiVal)
+        self.P1Button2keySpinBox.setValue(float(AsciiVal))
 
     def P1updateButton3(self):
-	self.P1Button3Value.setText(AsciiVal)
+        self.P1Button3keySpinBox.setValue(float(AsciiVal))
 
     def P1updateButton4(self):
-	self.P1Button4Value.setText(AsciiVal)
+        self.P1Button4keySpinBox.setValue(float(AsciiVal))
 
     def P1updateButton5(self):
-	self.P1Button5Value.setText(AsciiVal)
+        self.P1Button5keySpinBox.setValue(float(AsciiVal))
 
     def P1updateButton6(self):
-	self.P1Button6Value.setText(AsciiVal)
+        self.P1Button6keySpinBox.setValue(float(AsciiVal))
 
     def P1updateAutofire1(self):
-	self.P1Autofire1Value.setText(AsciiVal)
+        self.P1Autofire1keySpinBox.setValue(float(AsciiVal))
 
     def P1updateAutofire2(self):
-	self.P1Autofire2Value.setText(AsciiVal)
+        self.P1Autofire2keySpinBox.setValue(float(AsciiVal))
 
     def P1updateAutofire3(self):
-	self.P1Autofire3Value.setText(AsciiVal)
+        self.P1Autofire3keySpinBox.setValue(float(AsciiVal))
+
+    def P1updateReset(self):
+        self.P1ResetkeySpinBox.setValue(float(AsciiVal))
+
+    def P1updateMenu(self):
+        self.P1MenukeySpinBox.setValue(float(AsciiVal))
+
+    def P1updateService(self):
+        self.P1ServicekeySpinBox.setValue(float(AsciiVal))
+
+    def P1updateExit(self):
+        self.P1ExitkeySpinBox.setValue(float(AsciiVal))
+
+    def P1updateSixaxis(self):
+	if self.P1SixaxisPushButton.isChecked():
+           self.options["SIXAXIS"] = "1"
+	else:
+           self.options["SIXAXIS"] = "0"
+        
+
+    def change_value(self,event):
+        # P1
+        self.options["UP"] = "%.0f" % self.P1UpkeySpinBox.value()
+        self.options["DOWN"] = "%.0f" % self.P1DownkeySpinBox.value()
+        self.options["RIGHT"] = "%.0f" % self.P1RightkeySpinBox.value()
+        self.options["LEFT"] = "%.0f" % self.P1LeftkeySpinBox.value()
+        self.options["START"] = "%.0f" % self.P1StartkeySpinBox.value()
+        self.options["COIN"] = "%.0f" % self.P1CoinkeySpinBox.value()
+        self.options["BUTTON1"] = "%.0f" % self.P1Button1keySpinBox.value()
+        self.options["BUTTON2"] = "%.0f" % self.P1Button2keySpinBox.value()
+        self.options["BUTTON3"] = "%.0f" % self.P1Button3keySpinBox.value()
+        self.options["BUTTON4"] = "%.0f" % self.P1Button4keySpinBox.value()
+        self.options["BUTTON5"] = "%.0f" % self.P1Button5keySpinBox.value()
+        self.options["BUTTON6"] = "%.0f" % self.P1Button6keySpinBox.value()
+        self.options["AUTOFIRE1"] = "%.0f" % self.P1Autofire1keySpinBox.value()
+        self.options["AUTOFIRE2"] = "%.0f" % self.P1Autofire2keySpinBox.value()
+        self.options["AUTOFIRE3"] = "%.0f" % self.P1Autofire3keySpinBox.value()
+        self.options["RESET"] = "%.0f" % self.P1ResetkeySpinBox.value()
+        self.options["MENU"] = "%.0f" % self.P1MenukeySpinBox.value()
+        self.options["SERVICE"] = "%.0f" % self.P1ServicekeySpinBox.value()
+        self.options["EXIT"] = "%.0f" % self.P1ExitkeySpinBox.value()
 
     def SaveKeys(self):
+        orgConfigFile = open(Cps2_KeyCfgFile,"r")
 	try:
-		keyConfigFile = open(Cps2_KeyCfgFile,"w")
+	        copyFile = open(Cps2_KeyCfgFile + ".old" ,"w")
 	except:
-		QMessageBox.critical(self, "Warning",  "Cannot write " + Cps2_KeyCfgFile)
+		QMessageBox.critical(self, "Warning",  "Cannot write " + Cps2_KeyCfgFile + ".old")
 	else:
-		keyConfigFile.write(self.P1UpValue.text()+ "\n")
-		keyConfigFile.write(self.P1DownValue.text()+ "\n")
-		keyConfigFile.write(self.P1LeftValue.text()+ "\n")
-		keyConfigFile.write(self.P1RightValue.text()+ "\n")
-		keyConfigFile.write(self.P1StartValue.text()+ "\n")
-		keyConfigFile.write(self.P1CoinValue.text()+ "\n")
-		keyConfigFile.write(self.P1Button1Value.text()+ "\n")
-		keyConfigFile.write(self.P1Button2Value.text()+ "\n")
-		keyConfigFile.write(self.P1Button3Value.text()+ "\n")
-		keyConfigFile.write(self.P1Button4Value.text()+ "\n")
-		keyConfigFile.write(self.P1Button5Value.text()+ "\n")
-		keyConfigFile.write(self.P1Button6Value.text()+ "\n")
-		keyConfigFile.write(self.P1Autofire1Value.text()+ "\n")
-		keyConfigFile.write(self.P1Autofire2Value.text()+ "\n")
-		keyConfigFile.write(self.P1Autofire3Value.text()+ "\n")
-		keyConfigFile.close()
-		os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
-		           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
-		           string:"Key Configuration is succesfully saved"')
+		# Write the copy (.old)
+		for line in orgConfigFile.readlines():
+			copyFile.write(line)
+		orgConfigFile.close()
+		copyFile.close()
+		try:
+			newConfigFile = open(Cps2_KeyCfgFile,"w")
+		except:
+			QMessageBox.critical(self, "Warning",  "Cannot write " + Cps2_KeyCfgFile)
+		else:
+			newConfigFile.write("# Generated by cps2-gui\n")
+			for option in self.options:
+				newConfigFile.write(option + " " + self.options[option] + "\n")
+			newConfigFile.close()
+			os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
+			           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
+			           string:"Key Configuration is succesfully saved"')
 
 class JoykeyWindow(QDialog):
     def __init__(self, parent=None):
@@ -1037,36 +1124,36 @@ class MyKeyPressed(QPushButton):
     def event(self, event):
         if (event.type()==QEvent.KeyPress):
             # we have to get the SDL keysym
-	    global AsciiVal
+            global AsciiVal
             if (event.key() < 256):
-                AsciiVal = chr(ord(str.lower(chr(event.key()))))
+                AsciiVal = ord(str.lower(chr(event.key())))
             if (event.key() == 16777236):
-		# right
-                AsciiVal = "KEY_RIGHT";
-	    if (event.key() == 16777234):
+                # right
+                AsciiVal = 275;
+            if (event.key() == 16777234):
                 # left
-                AsciiVal = "KEY_LEFT";
+                AsciiVal = 276;
             if (event.key() == 16777235):
                 # up
-                AsciiVal = "KEY_UP";
+                AsciiVal = 273;
             if (event.key() == 16777237):
                 # down
-                AsciiVal = "KEY_DOWN";
+                AsciiVal = 274;
             if (event.key() == 16777219):
                 # BS
-                AsciiVal = "KEY_BS";
+                AsciiVal = 8;
             if (event.key() == 16777221):
                 # Return
-                AsciiVal = "KEY_ENTER";
+                AsciiVal = 271;
             if (event.key() == 16777248):
-                # R-Shift
-                AsciiVal = "KEY_RSHIFT";
+                # L-Shift
+                AsciiVal = 304;
             if (event.key() == 16777249):
-                # R-Control
-                AsciiVal = "KEY_RCONTROL";
+                # L-Control
+                AsciiVal = 306;
             if (event.key() == 16781571):
-                # R-Alt
-                AsciiVal = "KEY_RALT";
+                # L-Alt
+                AsciiVal = 313;
             self.emit(SIGNAL("keyPressed"))
 
         return QPushButton.event(self, event)
